<?php
/**
 * @file
 * Contains \Drupal\entity_link_display\Plugin\Field\FieldType\ViewModeLinkComputedField.
 */
namespace Drupal\entity_link_display\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemList;
use Drupal\Core\TypedData\ComputedItemListTrait;
use Drupal\Core\Link;


/**
 * Computed field that returns the link to the node.
 */
class ViewModeLinkComputedField extends FieldItemList {
    use ComputedItemListTrait;
  
    protected function computeValue() {
      $entity = $this->getEntity();
  
      if ($entity->id() && $entity->hasLinkTemplate('canonical')) {
        try {
          $url = $entity->toUrl('canonical', ['absolute' => TRUE]);
          $link_title = t('Display Link');
  
          // Create a link item with uri and title.
          $this->list[0] = $this->createItem(0, [
            'uri' => $url->toString(),
            'title' => $link_title,
          ]);
        }
        catch (\Exception $e) {
          $this->list[0] = $this->createItem(0, ['uri' => '', 'title' => '']);
        }
      }
      else {
        $this->list[0] = $this->createItem(0, ['uri' => '', 'title' => '']);
      }
    }
  }
